@@ -787,10 +787,19 @@ AsyncSocket_MsgError(int asyncSockError)   // IN
       result = MSGID(asyncsocket.proxyconnectfailed)
                      "Connection failed through proxy";
       break;
+   case ASOCKERR_PROXY_INVALID_OR_NOT_SUPPORTED:
+      result = MSGID(asyncsocket.proxyinvalidornotsupported)
+                     "Invalid or not supported type proxy";
+      break;
    case ASOCKERR_WEBSOCK_UPGRADE_NOT_FOUND:
       result = MSGID(asyncsocket.websocketupgradefailed)
                      "Upgrade to websocket error: NOT FOUND, status code 404";
       break;
+   case ASOCKERR_WEBSOCK_TOO_MANY_CONNECTION:
+      result = MSGID(asyncsocket.websockettoomanyconnection)
+                     "The server-side WebSocket connection limit has been exceeded,"
+                     " HTTP status code 429";
+      break;
    }
 
    if (!result) {
