@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2016-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 2016-2020 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -242,6 +242,40 @@ AsyncSocket_GetRemoteIPStr(AsyncSocket *asock,      // IN
 }
 
 
+/*
+ *----------------------------------------------------------------------------
+ *
+ * AsyncSocket_GetRemotePort --
+ *
+ *      Given an AsyncSocket object, returns the remote port associated
+ *      with it, or an error if the request is meaningless for the underlying
+ *      connection.
+ *
+ * Results:
+ *      ASOCKERR_SUCCESS or ASOCKERR_INVAL.
+ *
+ * Side effects:
+ *
+ *
+ *----------------------------------------------------------------------------
+ */
+
+int
+AsyncSocket_GetRemotePort(AsyncSocket *asock,  // IN
+                          uint32 *port)        // OUT
+{
+   int ret;
+   if (VALID(asock, getRemotePort)) {
+      AsyncSocketLock(asock);
+      ret = VT(asock)->getRemotePort(asock, port);
+      AsyncSocketUnlock(asock);
+   } else {
+      ret = ASOCKERR_INVAL;
+   }
+   return ret;
+}
+
+
 /*
  *----------------------------------------------------------------------------
  *
@@ -1440,7 +1474,7 @@ AsyncSocket_SetWebSocketCookie(AsyncSocket *asock,      // IN
                                const char *path,        // IN
                                const char *sessionId)   // IN
 {
-   int ret = ASOCKERR_GENERIC;
+   int ret = ASOCKERR_INVAL;
    if (VALID(asock, setWebSocketCookie)) {
       AsyncSocketLock(asock);
       ret = VT(asock)->setWebSocketCookie(asock, clientData, path, sessionId);
@@ -1514,6 +1548,38 @@ AsyncSocket_GetWebSocketProtocol(AsyncSocket *asock)  // IN
 }
 
 
+/*
+ *----------------------------------------------------------------------------
+ *
+ * AsyncSocket_SetDelayWebSocketUpgradeResponse --
+ *
+ *      Set a flag for whether or not to not automatically send the websocket
+ *      upgrade response upon receiving the websocket upgrade request.
+ *
+ * Results:
+ *      None.
+ *
+ * Side effects:
+ *      None.
+ *
+ *----------------------------------------------------------------------------
+ */
+
+int
+AsyncSocket_SetDelayWebSocketUpgradeResponse(AsyncSocket *asock,                  // IN
+                                             Bool delayWebSocketUpgradeResponse)  // IN
+{
+   int ret = ASOCKERR_INVAL;
+   if (VALID(asock, setDelayWebSocketUpgradeResponse)) {
+      AsyncSocketLock(asock);
+      ret = VT(asock)->setDelayWebSocketUpgradeResponse(asock,
+                                                        delayWebSocketUpgradeResponse);
+      AsyncSocketUnlock(asock);
+   }
+   return ret;
+}
+
+
 /*
  *----------------------------------------------------------------------------
  *
