@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2018 VMware, Inc. All rights reserved.
+ * Copyright (C) 1998-2020 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -32,13 +32,14 @@ struct DirectoryEntry;
 #endif
 
 #include "dbllnklst.h"
-#include "hgfsProto.h"
 #include "cpName.h"     // for HgfsNameStatus
+#include "hgfsCache.h"
+#include "hgfsProto.h"
+#include "hgfsServer.h" // for the server public types
 #include "hgfsServerPolicy.h"
 #include "hgfsUtil.h"   // for HgfsInternalStatus
-#include "vm_atomic.h"
 #include "userlock.h"
-#include "hgfsServer.h" // for the server public types
+#include "vm_atomic.h"
 
 
 #ifndef VMX86_TOOLS
@@ -81,18 +82,29 @@ struct DirectoryEntry;
 
 #define DOLOG(_min)     ((_min) <= LGLEVEL)
 
-#define LOG(_level, args)                                  \
-   do {                                                    \
-      if (DOLOG(_level)) {                                 \
-         Debug(LGPFX_FMT, LGPFX, __FUNCTION__);            \
-         Debug args;                                       \
-      }                                                    \
+/* gcc needs special syntax to handle zero-length variadic arguments */
+#if defined(_MSC_VER)
+#define LOG(_level, fmt, ...)                                     \
+   do {                                                           \
+      if (DOLOG(_level)) {                                        \
+         Debug(LGPFX_FMT fmt, LGPFX , __FUNCTION__, __VA_ARGS__); \
+      }                                                           \
    } while (0)
+#else
+#define LOG(_level, fmt, ...)                                      \
+   do {                                                            \
+      if (DOLOG(_level)) {                                         \
+         Debug(LGPFX_FMT fmt, LGPFX, __FUNCTION__, ##__VA_ARGS__); \
+      }                                                            \
+   } while (0)
+#endif
 
 #endif // VNMX86_TOOLS
 
 #define HGFS_DEBUG_ASYNC   (0)
 
+typedef uintptr_t HOM_HANDLE;
+
 typedef struct HgfsTransportSessionInfo HgfsTransportSessionInfo;
 
 /* Identifier for a local file */
@@ -385,7 +397,13 @@ typedef struct HgfsSessionInfo {
    uint32 numberOfCapabilities;
 
    /* Asynchronous request handling. */
-   HgfsAsyncRequestInfo  asyncRequestsInfo;
+   HgfsAsyncRequestInfo asyncRequestsInfo;
+
+   /* Cache for symlink check status. */
+   HgfsCache *symlinkCache;
+
+   /* Cache for file attributes. */
+   HgfsCache *fileAttrCache;
 } HgfsSessionInfo;
 
 /*
@@ -504,6 +522,16 @@ typedef struct HgfsCreateSessionInfo {
    HgfsSessionFlags flags;       /* Session capability flags. */
 } HgfsCreateSessionInfo;
 
+typedef struct HgfsSymlinkCacheEntry {
+   HOM_HANDLE handle;            /* File handle. */
+   HgfsNameStatus nameStatus;    /* Symlink check status. */
+} HgfsSymlinkCacheEntry;
+
+typedef struct HgfsFileAttrCacheEntry {
+   HOM_HANDLE handle;            /* File handle. */
+   HgfsFileAttrInfo attr;        /* Attributes of entry. */
+} HgfsFileAttrCacheEntry;
+
 Bool
 HgfsCreateAndCacheFileNode(HgfsFileOpenInfo *openInfo, // IN: Open info struct
                            HgfsLocalId const *localId, // IN: Local unique file ID
