@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2014-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 2014-2020 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -34,6 +34,7 @@
 #include <sys/socket.h>
 #include <sys/stat.h>
 #include <errno.h>
+#include <limits.h>
 #if defined(__FreeBSD__) || defined(__APPLE__)
 # include <sys/sysctl.h>
 # include <ifaddrs.h>
@@ -77,7 +78,7 @@
  * ISC, OTOH, provided accessing IPv6 servers via a res_getservers API.
  * TTBOMK, this went public with BIND 8.3.0.  Unfortunately __RES wasn't
  * bumped for this release, so instead I'm going to assume that appearance with
- * that release of a new macro, RES_F_DNS0ERR, implies this API is available.
+ * that release of a new macro, RES_F_EDNS0ERR, implies this API is available.
  * (For internal builds, we'll know instantly when a build breaks.  The down-
  * side is that this could cause some trouble for open-vm-tools users. ,_,)
  *
@@ -163,7 +164,11 @@ static char *ValidateConvertAddress(const struct sockaddr *addr);
 
 #ifdef USE_RESOLVE
 static Bool RecordResolverInfo(NicInfoV3 *nicInfo);
-static void RecordResolverNS(DnsConfigInfo *dnsConfigInfo);
+static void RecordResolverNS(res_state resp, DnsConfigInfo *dnsConfigInfo);
+static int AddResolverNSInfo(DnsConfigInfo *dnsConfigInfo, struct sockaddr *sap);
+#   ifndef RESOLVER_IPV6_GETSERVERS
+static void PrintResolverNSInfo(res_state resp);
+#   endif
 #endif
 
 
@@ -239,6 +244,39 @@ CountNetmaskBitsV6(struct sockaddr *netmask)
 }
 
 
+/*
+ ******************************************************************************
+ * IpEntryMatchesDevice --                                               */ /**
+ *
+ * @brief Check if the IP entry matches the network device.
+ *
+ * @param[in]   devName the device name
+ * @param[in]   label   the IP entry name
+ *
+ * @retval      TRUE if the IP entry name matches the device name
+ *              FALSE otherwise.
+ *
+ ******************************************************************************
+ */
+
+static Bool
+IpEntryMatchesDevice(const char *devName,
+                     const char *label)
+{
+   char *p;
+   size_t n;
+
+   if ((p = strchr(label, ':')) != NULL) {
+      n = p - label;
+   } else {
+      n = strlen(label);
+   }
+
+   /* compare sub string label[0, n) with a null terminated string devName */
+   return (0 == strncmp(devName, label, n) && '\0' == devName[n]);
+}
+
+
 /*
  ******************************************************************************
  * GuestInfoGetInterface --                                              */ /**
@@ -266,8 +304,6 @@ GuestInfoGetInterface(struct ifaddrs *ifaddrs,
     * records are intermingled with AF_INET and AF_INET6 records.
     */
    for (pkt = ifaddrs; pkt != NULL; pkt = pkt->ifa_next) {
-      GuestNicV3 *nic;
-      struct ifaddrs *ip;
       struct sockaddr_ll *sll = (struct sockaddr_ll *)pkt->ifa_addr;
 
       if (GuestInfo_IfaceGetPriority(pkt->ifa_name) != priority ||
@@ -277,6 +313,8 @@ GuestInfoGetInterface(struct ifaddrs *ifaddrs,
 
       if (sll != NULL && sll->sll_family == AF_PACKET) {
          char macAddress[NICINFO_MAC_LEN];
+         GuestNicV3 *nic;
+         struct ifaddrs *ip;
 
          /*
           * PR 2193804:
@@ -305,13 +343,13 @@ GuestInfoGetInterface(struct ifaddrs *ifaddrs,
             break;
          }
          /*
-          * Now look for all IPv4 and IPv6 interfaces with the same
-          * interface name as the current AF_PACKET interface.
+          * Now look for all IPv4 and IPv6 interfaces that match
+          * the current AF_PACKET interface.
           */
          for (ip = ifaddrs; ip != NULL; ip = ip->ifa_next) {
             struct sockaddr *sa = (struct sockaddr *)ip->ifa_addr;
             if (sa != NULL &&
-                strncmp(ip->ifa_name, pkt->ifa_name, IFNAMSIZ) == 0) {
+                IpEntryMatchesDevice(pkt->ifa_name, ip->ifa_name)) {
                int family = sa->sa_family;
                Bool goodAddress = FALSE;
                unsigned nBits = 0;
@@ -391,7 +429,7 @@ GuestInfoGetNicInfo(unsigned int maxIPv4Routes,
        intf_loop(intf, ReadInterfaceDetailsNormal, nicInfo) < 0 ||
        intf_loop(intf, ReadInterfaceDetailsLowPriority, nicInfo) < 0) {
       intf_close(intf);
-      g_debug("Error, negative result from intf_loop\n");
+      g_debug("%s: Error, negative result from intf_loop\n", __FUNCTION__);
       return FALSE;
    }
 
@@ -466,7 +504,6 @@ GuestInfoGetPrimaryIP(void)
 {
    struct ifaddrs *ifaces;
    struct ifaddrs *curr;
-   char *ipstr = NULL;
    char *currIpstr = NULL;
    NicInfoPriority currPri = NICINFO_PRIORITY_MAX;
 
@@ -475,7 +512,7 @@ GuestInfoGetPrimaryIP(void)
     * to traverse and places a pointer to it in ifaces.
     */
    if (getifaddrs(&ifaces) < 0) {
-      return ipstr;
+      return NULL;
    }
 
    /*
@@ -484,6 +521,7 @@ GuestInfoGetPrimaryIP(void)
     * the first non-loopback, internet interface in the interface list.
     */
    for (curr = ifaces; curr != NULL; curr = curr->ifa_next) {
+      char *ipstr = NULL;
       int currFamily;
 
       /*
@@ -509,13 +547,15 @@ GuestInfoGetPrimaryIP(void)
          if (pri < currPri) {
             g_debug("%s: ifa_name=%s, pri=%d, currPri=%d, ipstr=%s",
                     __FUNCTION__, curr->ifa_name, pri, currPri, ipstr);
-            g_free(currIpstr);
+            free(currIpstr);
             currIpstr = ipstr;
             currPri = pri;
             if (pri == NICINFO_PRIORITY_PRIMARY) {
                /* not going to find anything better than that */
                break;
             }
+         } else {
+            free(ipstr);
          }
       }
    }
@@ -633,8 +673,6 @@ ReadInterfaceDetails(const struct intf_entry *entry, // IN
 
    if (entry->intf_type == INTF_TYPE_ETH &&
        entry->intf_link_addr.addr_type == ADDR_TYPE_ETH) {
-      GuestNicV3 *nic = NULL;
-      char macAddress[NICINFO_MAC_LEN];
 
       /*
        * There is a race where the guest info plugin might be iterating over the
@@ -644,6 +682,9 @@ ReadInterfaceDetails(const struct intf_entry *entry, // IN
        * pick up any changes.
        */
       if (entry->intf_link_addr.addr_type == ADDR_TYPE_ETH) {
+         char macAddress[NICINFO_MAC_LEN];
+         GuestNicV3 *nic = NULL;
+
          Str_Sprintf(macAddress, sizeof macAddress, "%s",
                      addr_ntoa(&entry->intf_link_addr));
 
@@ -797,8 +838,11 @@ RecordResolverInfo(NicInfoV3 *nicInfo)  // OUT
    DnsConfigInfo *dnsConfigInfo = NULL;
    char namebuf[DNSINFO_MAX_ADDRLEN + 1];
    char **s;
+   struct __res_state res;
 
-   if (res_init() == -1) {
+   memset(&res, 0, sizeof res);
+   if (res_ninit(&res) == -1) {
+      g_warning("%s: Resolver res_init failed.\n", __FUNCTION__);
       return FALSE;
    }
 
@@ -819,17 +863,17 @@ RecordResolverInfo(NicInfoV3 *nicInfo)  // OUT
     */
    dnsConfigInfo->domainName =
       Util_SafeCalloc(1, sizeof *dnsConfigInfo->domainName);
-   *dnsConfigInfo->domainName = Util_SafeStrdup(_res.defdname);
+   *dnsConfigInfo->domainName = Util_SafeStrdup(res.defdname);
 
    /*
     * Name servers.
     */
-   RecordResolverNS(dnsConfigInfo);
+   RecordResolverNS(&res, dnsConfigInfo);
 
    /*
     * Search suffixes.
     */
-   for (s = _res.dnsrch; *s; s++) {
+   for (s = res.dnsrch; *s; s++) {
       DnsHostname *suffix;
 
       /* Check to see if we're going above our limit. See bug 605821. */
@@ -849,14 +893,75 @@ RecordResolverInfo(NicInfoV3 *nicInfo)  // OUT
     */
    nicInfo->dnsConfigInfo = dnsConfigInfo;
 
+   res_nclose(&res);
+
    return TRUE;
 
 fail:
    VMX_XDR_FREE(xdr_DnsConfigInfo, dnsConfigInfo);
    free(dnsConfigInfo);
+   res_nclose(&res);
+
    return FALSE;
 }
 
+/*
+ ******************************************************************************
+ * RecordResolverNSResolvConf                                            */ /**
+ *
+ * @brief Parses file in resolv.conf format, and copies name servers to
+ * @a dnsConfigInfo.
+ *
+ * @param[in]  file             path of file to read
+ * @param[out] dnsConfigInfo    Destination DnsConfigInfo container
+ *
+ ******************************************************************************
+ */
+
+static void
+RecordResolverNSResolvConf(const char *file, DnsConfigInfo *dnsConfigInfo)
+{
+   FILE *fptr;
+
+   fptr = fopen(file, "rt");
+   if (fptr != NULL) {
+      char line[256];
+      while (fgets(line, sizeof(line), fptr)) {
+         char *tok, *saveptr = NULL;
+         tok = strtok_r(line, " \t", &saveptr);
+         if ((tok != NULL) && (strcmp(tok, "nameserver") == 0)) {
+            char *val;
+            struct sockaddr_in sa4;
+            struct sockaddr_in6 sa6;
+            val = strtok_r(NULL, " \t\r\n", &saveptr);
+            if (val == NULL) {
+               g_warning("%s: no value for nameserver in %s\n",
+                         __FUNCTION__, file);
+            } else if (inet_pton(AF_INET, val, &sa4.sin_addr)) {
+               sa4.sin_family = AF_INET;
+               if (0 == AddResolverNSInfo(dnsConfigInfo,
+                                          (struct sockaddr *) &sa4)) {
+                  /* Can't add more DNS entries to dnsConfigInfo, break loop */
+                  break;
+               }
+            } else if (inet_pton(AF_INET6, val, &sa6.sin6_addr)) {
+               sa6.sin6_family = AF_INET6;
+               if (0 == AddResolverNSInfo(dnsConfigInfo,
+                                          (struct sockaddr *) &sa6)) {
+                  /* Can't add more DNS entries to dnsConfigInfo, break loop */
+                  break;
+               }
+            } else {
+               g_warning("%s: invalid IP address '%s' in %s ignored\n",
+                         __FUNCTION__, val, file);
+            }
+         }
+      }
+      fclose(fptr);
+   } else {
+      g_warning("%s: could not open file '%s': %s\n", __FUNCTION__, file, strerror(errno));
+   }
+}
 
 /*
  ******************************************************************************
@@ -864,90 +969,348 @@ fail:
  *
  * @brief Copies name servers used by resolver(3) to @a dnsConfigInfo.
  *
+ * @param[in]  resp             res_state, pointer to a resolver(3) state
+ *                              structure.
  * @param[out] dnsConfigInfo    Destination DnsConfigInfo container.
  *
  ******************************************************************************
  */
 
 static void
-RecordResolverNS(DnsConfigInfo *dnsConfigInfo) // IN
+RecordResolverNS(res_state resp, DnsConfigInfo *dnsConfigInfo) // IN
 {
    int i;
+   char resolvConf[PATH_MAX];
+
+   /*
+    * If systemd-resolved is used we want to report the external DNS
+    * server, not the locally installed one. We detect this by checking
+    * if /etc/resolv.conf is a link to /run/systemd/resolve/stub-resolv.conf.
+    * In that case, /run/systemd/resolve/resolv.conf will hold the actual
+    * DNS server. See
+    * https://www.freedesktop.org/software/systemd/man/systemd-resolved.service.html
+    */
+   if (realpath("/etc/resolv.conf", resolvConf) != NULL) {
+      if (strcmp(resolvConf, "/run/systemd/resolve/stub-resolv.conf") == 0) {
+         const char *file = "/run/systemd/resolve/resolv.conf";
+         if (access(file, R_OK) != -1) {
+            RecordResolverNSResolvConf(file, dnsConfigInfo);
+            return;
+         } else {
+            g_debug("%s: could not access %s for reading: %s\n",
+                    __FUNCTION__, file, strerror(errno));
+         }
+      }
+   }
 
 #if defined RESOLVER_IPV6_GETSERVERS
    {
       union res_sockaddr_union *ns;
-      ns = Util_SafeCalloc(_res.nscount, sizeof *ns);
-      if (res_getservers(&_res, ns, _res.nscount) != _res.nscount) {
-         g_warning("%s: res_getservers failed.\n", __func__);
-         return;
-      }
-      for (i = 0; i < _res.nscount; i++) {
-         struct sockaddr *sa = (struct sockaddr *)&ns[i];
-         if (sa->sa_family == AF_INET || sa->sa_family == AF_INET6) {
-            TypedIpAddress *ip;
-
-            /* Check to see if we're going above our limit. See bug 605821. */
-            if (dnsConfigInfo->serverList.serverList_len == DNSINFO_MAX_SERVERS) {
-               g_message("%s: dns server limit (%d) reached, skipping overflow.",
-                         __FUNCTION__, DNSINFO_MAX_SERVERS);
+      ns = Util_SafeCalloc(resp->nscount, sizeof *ns);
+      if (res_getservers(resp, ns, resp->nscount) != resp->nscount) {
+         g_warning("%s: res_getservers failed.\n", __FUNCTION__);
+         /* fallthrough to free & return */
+      } else {
+         for (i = 0; i < resp->nscount; i++) {
+            if (0 == AddResolverNSInfo(
+                        dnsConfigInfo,
+                        (struct sockaddr *)&ns[i])) {
+               /* Can't add more DNS entries to dnsConfigInfo, break loop */
                break;
             }
-
-            ip = XDRUTIL_ARRAYAPPEND(dnsConfigInfo, serverList, 1);
-            ASSERT_MEM_ALLOC(ip);
-            GuestInfoSockaddrToTypedIpAddress(sa, ip);
+            /* Else: if < 0, reason already logged in AddResolverNSInfo */
          }
       }
+
+      /* free and return */
+      free(ns);
    }
 #else                                   // if defined RESOLVER_IPV6_GETSERVERS
    {
       /*
-       * Name servers (IPv4).
+       * GLIBC resolv implementation details to consider...
+       *
+       * In mixed mode, where both IPv4 and IPv6 nameserver are configured,
+       * both arrays (__res_state.nsaddr_list, __res_state._u._ext.nsaddrs) are
+       * combined to for the list of nameservers.
+       *
+       * The __res_state.nscount value is limited to MAXNS and represent the
+       * current number of 'managed' or 'valid' nameserver entries across
+       * both list.
+       *
+       * However, not everyone manages the arrays the same way (of course...).
+       *
+       * Assume resolv.conf:
+       *    nameserver A (IPv4)
+       *    nameserver B (IPv6)
+       *    nameserver C (IPv4)
+       *
+       * Case 1: front-loaded
+       *         IPv4 entries are front-loaded in __res_state.nsaddr_list[] and
+       *         IPv6 entries are positional in __res_state._u._ext.nsaddrs[]
+       *         position matches /etc/resolv.conf order
+       *           __res_state.nsaddr_list | __res_state._u._ext.nsaddrs
+       *                  -----------------+--------------------
+       *                          A        |       -
+       *                          C        |       B
+       *                          -        |       -
+       *
+       * Case 2: staggered / positional
+       *         IPv4 entries are staggered with IPv6 entries, thus positional
+       *         in both arrays relative to each other.
+       *           __res_state.nsaddr_list | __res_state._u._ext.nsaddrs
+       *                  -----------------+--------------------
+       *                          A        |       -
+       *                          -        |       B
+       *                          C        |       -
+       *
+       * Both cases are enhanced by different IPv4 data management features:
+       *    Variation 1: IPv4 sin_family is not cleared.
+       *    Variation 2: IPv4 sin_family is cleared (set to 0)
+       *
+       * Distro+release | nscount6 |  Case      | sin_family  |
+       * =======================================================================
+       *  RHEL 6.10     |   yes    | front-load | not cleared |
+       *  RHEL 7.2      |   yes    | front-load | not cleared |
+       *  RHEL 7.6      |   no     | staggered  |  post-fix   |
+       * -----------------------------------------------------------------------
+       *  SLES 11-sp3   |   yes    | staggered  | not cleared | **bad
+       *  SLES 12       |   no     | staggered  |   cleared   |
+       * -----------------------------------------------------------------------
+       *  FreeBSD 11    |  -na-    |    -na-    |     -na-    | res_getservers
+       * -----------------------------------------------------------------------
+       *  Ubuntu 12.04  |   yes    | staggered  | not cleared | **bad
+       *  Ubuntu 14.04  |   yes    | staggered  | not cleared | **bad
+       *  Ubuntu 18.04  |   no     | staggered  |   cleared   |
+       * -----------------------------------------------------------------------
+       *  Fedora 24     |   no     | staggered  |   cleared   |
+       * =======================================================================
+       *
+       * Restarting the process (service: vmtoolsd) resets the IPv4 array and
+       * fixes issues that arise with "staggered + not cleared" combos, as well
+       * as clearing out DNS reporting info issues for ealier versions.
+       *
+       * Fix for PR 2302591:
+       *  - Move away from using the _res global __res_state var and instead use
+       *    a locally allocated __res_state structure.
+       *     *  Ensures the IPv4 data is reset every time we collect DNS info.
+       *     *  Calling res_nclose on the resolver structure and freeing it at
+       *        the end of the configuration update ensure the IPv6 structure
+       *        are not leaked (see: RecordResolverInfo())
+       *  - Log the res_state nameserver configuration for debugging.
+       *  - Validate and compute nscount4, nscount6 values
+       *  - Pick DNS entries from both list, with the IPv6 array driving the
+       *    order of the entries. Increment the '4 or '6 count when a DNS entry
+       *    is selected.
+       *
+       * Clearing the IPv4 sin_family is REQUIRED to support all cases.
+       * Otherwise the "staggered+'not cleared'" and "front-load" scenarios are
+       * indistinguishable.
+       *
+       * Manually clearing the IPv4 sin_family field can be done after close if
+       * continued use of res_init() and the _res global is desirable.
        */
-      for (i = 0; i < MAXNS; i++) {
-         struct sockaddr_in *sin = &_res.nsaddr_list[i];
-         if (sin->sin_family == AF_INET) {
-            TypedIpAddress *ip;
+      int addRC;
+      int nscount4 = 0; /* number of IPv4 entries collected */
+      int nscount6 = 0; /* number of IPv6 entries collected */
 
-            /* Check to see if we're going above our limit. See bug 605821. */
-            if (dnsConfigInfo->serverList.serverList_len == DNSINFO_MAX_SERVERS) {
-               g_message("%s: dns server limit (%d) reached, skipping overflow.",
-                         __FUNCTION__, DNSINFO_MAX_SERVERS);
-               break;
-            }
+      PrintResolverNSInfo(resp);
 
-            ip = XDRUTIL_ARRAYAPPEND(dnsConfigInfo, serverList, 1);
-            ASSERT_MEM_ALLOC(ip);
-            GuestInfoSockaddrToTypedIpAddress((struct sockaddr *)sin, ip);
-         }
-      }
-#   if defined RESOLVER_IPV6_EXT
       /*
-       * Name servers (IPv6).
+       * Collect DNS entries
+       *   There are up to __res_state.nscount valid entries, and nscount is
+       *   limited to the array size (MAXNS).
+       *   Loop up to __res_state.nscount, or until the target number of entries
+       *   (IPv4 and IPv6) are collected.
+       *   Requires IPv4 sin_family to be set to 0 for unused entries in
+       *   __res_state.nsaddr_list[].
        */
-      for (i = 0; i < MAXNS; i++) {
-         struct sockaddr_in6 *sin6 = _res._u._ext.nsaddrs[i];
-         if (sin6) {
-            TypedIpAddress *ip;
-
-            /* Check to see if we're going above our limit. See bug 605821. */
-            if (dnsConfigInfo->serverList.serverList_len == DNSINFO_MAX_SERVERS) {
-               g_message("%s: dns server limit (%d) reached, skipping overflow.",
-                         __FUNCTION__, DNSINFO_MAX_SERVERS);
+      for (i = 0; i < resp->nscount && ((nscount4 + nscount6) < resp->nscount); i++) {
+#   if defined RESOLVER_IPV6_EXT
+         /*
+          * IPv6 list is authoritative at a given index, process it first
+          */
+         if (resp->_u._ext.nsaddrs[i]) {
+            /* Has IPv6 nameserver at index */
+            addRC = AddResolverNSInfo(
+                       dnsConfigInfo,
+                       (struct sockaddr *)resp->_u._ext.nsaddrs[i]);
+            if (addRC == 0) {
+               /* Can't add more DNS entries to dnsConfigInfo, break loop */
                break;
+            } else if (addRC > 0) {
+               /* update count only if added */
+               nscount6++;
             }
-
-            ip = XDRUTIL_ARRAYAPPEND(dnsConfigInfo, serverList, 1);
-            ASSERT_MEM_ALLOC(ip);
-            GuestInfoSockaddrToTypedIpAddress((struct sockaddr *)sin6, ip);
+            /* Else: IPv6.sin6_family != AF_INET6 or other issues already
+             *       logged in AddResolverNSInfo
+             */
          }
+         /* Else: null entry indicates no IPv6 at that position */
+#   endif
+
+         if (resp->nsaddr_list[i].sin_family == AF_INET) {
+            /* Has IPv4 nameserver at index */
+            addRC = AddResolverNSInfo(
+                       dnsConfigInfo,
+                       (struct sockaddr *)(&resp->nsaddr_list[i]));
+            if (addRC == 0){
+               /* Can't add more DNS entries to dnsConfigInfo, break loop */
+               break;
+            } else if (addRC > 0) {
+               /* update count only if added */
+               nscount4++;
+            }
+            /* Else: issue logged in AddResolverNSInfo */
+         }
+         /* Else: IPv4.sin_family == 0, it means a 'free' slot. */
+      } /* for nscount and one of the total count is < nscount */
+
+      if ((nscount4 + nscount6) < resp->nscount) {
+         /*
+          * Not all expected nameserver entries were collected
+          */
+         g_warning(
+            "%s: dns update canceled, index=%d, ns=%d, IPv4=%d, IPv6=%d",
+            __FUNCTION__,
+            i, resp->nscount, nscount4, nscount6);
       }
-#   endif                               //    if defined RESOLVER_IPV6_EXT
    }
 #endif                                  // if !defined RESOLVER_IPV6_GETSERVERS
 }
 
+/*
+ ******************************************************************************
+ * AddResolverNSInfo --                                                  */ /**
+ *
+ * @brief Add a nameserver IP address from resolver(3) subsystem to the
+ *        DnsConfigInfo container.
+ *
+ * @param[out] dnsConfigInfo  Destination DnsConfigInfo container.
+ * @param[in]  sap            The sockaddr structure containing the IP address
+ *
+ * @retval -1    IP address not added due to wrong or invalid parameter.
+ * @retval  0    IP address not added due to limit reached @a dnsConfigInfo.
+ * @retval  1    IP address added to @a dnsConfigInfo or otherwise.
+ *
+ ******************************************************************************
+ */
+static int
+AddResolverNSInfo(DnsConfigInfo *dnsConfigInfo, struct sockaddr *sap)
+{
+   TypedIpAddress *ip;
+
+   ASSERT(sap != NULL);
+   ASSERT(dnsConfigInfo != NULL);
+
+   if (sap->sa_family != AF_INET
+       && sap->sa_family != AF_INET6) {
+      /* Not a supported address family */
+      g_debug("%s: unhandled address family (%d)", __FUNCTION__, sap->sa_family);
+      return -1;
+   }
+
+   /* Check to see if we're going above our limit. See bug 605821. */
+   if (dnsConfigInfo->serverList.serverList_len == DNSINFO_MAX_SERVERS) {
+      g_message("%s: dns server limit (%d) reached, skipping overflow.",
+         __FUNCTION__, DNSINFO_MAX_SERVERS);
+      return 0;
+   }
+
+   ip = XDRUTIL_ARRAYAPPEND(dnsConfigInfo, serverList, 1);
+   ASSERT_MEM_ALLOC(ip);
+   GuestInfoSockaddrToTypedIpAddress(sap, ip);
+   return 1;
+}
+
+#   ifndef RESOLVER_IPV6_GETSERVERS
+/*
+ ******************************************************************************
+ * PrintResolverNSInfo --                                                */ /**
+ *
+ * @brief log the resolver(3) subsystem state about nameservers
+ *
+ * @param[in] resp    res_state, pointer to a resolver(3) state structure.
+ *
+ ******************************************************************************
+ */
+static void
+PrintResolverNSInfo(res_state resp)
+{
+   /*
+    * Init IPv6 state for unsupported case
+    * Keep the message short < INET_ADDRSTRLEN for both v4 & v6
+    */
+   char ipv6Buff[INET6_ADDRSTRLEN+1] = "no-support";
+   char ipv4Buff[INET_ADDRSTRLEN+1];
+   int nscount = 0;
+   int nscount6 = 0;
+   int nscount4 = 0;
+   int i;
+
+   /* Split the counts per GLIBC 2.11+ source */
+   nscount = resp->nscount;
+#   ifdef RESOLVER_IPV6_EXT
+   nscount6 = resp->_u._ext.nscount6;
+#   endif
+   nscount4 = nscount - nscount6;
+
+   g_debug(
+      "Resolver State: id=%d Count=%d, IPv4=%d, IPv6=%d",
+       resp->id, nscount, nscount4, nscount6);
+
+   for (i = 0; i < MAXNS; i++) {
+#   ifdef RESOLVER_IPV6_EXT
+      /*
+       * Set IPv6 entry status
+       */
+      if (resp->_u._ext.nsaddrs[i] != NULL) {
+         if (resp->_u._ext.nsaddrs[i]->sin6_family == AF_INET6) {
+            const char *cvRes = inet_ntop(AF_INET6,
+                             &resp->_u._ext.nsaddrs[i]->sin6_addr,
+                             ipv6Buff, INET6_ADDRSTRLEN);
+            if (cvRes == NULL) {
+               /* Failed to output IPv6 address to buffer */
+               int errsv = errno;
+               /* Keep the message short < INET_ADDRSTRLEN for both v4 & v6 */
+               Str_Sprintf(ipv6Buff, sizeof ipv6Buff, "ntop-fail:%d", errsv);
+            }
+         } else {
+            /* Keep the message short < INET_ADDRSTRLEN for both v4 & v6 */
+            Str_Sprintf(ipv6Buff, sizeof ipv6Buff, "AF:%02d",
+              resp->_u._ext.nsaddrs[i]->sin6_family);
+         }
+      } else {
+         /* Keep the message short < INET_ADDRSTRLEN for both v4 & v6 */
+         Str_Sprintf(ipv6Buff, sizeof ipv6Buff, "no-entry");
+      }
+#   endif
+
+      /*
+       * Set IPv4 entry status
+       */
+      if (resp->nsaddr_list[i].sin_family == AF_INET) {
+         const char *cvRes = inet_ntop(AF_INET,
+                          &resp->nsaddr_list[i].sin_addr,
+                          ipv4Buff, INET_ADDRSTRLEN);
+         if (cvRes == NULL) {
+            /* Failed to output IPv4 address to buffer */
+            int errsv = errno;
+            /* Keep the message short < INET_ADDRSTRLEN for both v4 & v6 */
+            Str_Sprintf(ipv4Buff, sizeof ipv4Buff, "ntop-fail:%d", errsv);
+         }
+      } else {
+         /* Keep the message short < INET_ADDRSTRLEN for both v4 & v6 */
+         Str_Sprintf(ipv4Buff, sizeof ipv4Buff, "AF:%02d",
+           resp->nsaddr_list[i].sin_family);
+      }
+
+      g_debug(
+         "Resolver State: id=%d Lists[%d] - IPv4(%s) - IPv6(%s)",
+         resp->id, i, ipv4Buff, ipv6Buff);
+   }
+}
+#   endif // ifndef RESOLVER_IPV6_GETSERVERS
 #endif // USE_RESOLVE
 
 
