@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 1998-2020 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -270,9 +270,7 @@ ProcMgr_ListProcesses(void)
     * with the seconds since epoch that the system booted up.
     */
    if (0 == hostStartTime) {
-      FILE *uptimeFile = NULL;
-
-      uptimeFile = fopen("/proc/uptime", "r");
+      FILE *uptimeFile = fopen("/proc/uptime", "r");
       if (NULL != uptimeFile) {
          double secondsSinceBoot;
          char *realLocale;
@@ -393,6 +391,13 @@ ProcMgr_ListProcesses(void)
          int exeLen;
          char exeRealPath[1024];
 
+         /*
+          * This readlink() call on the "exe" file of the current /proc
+          * entry is not intended as a check on the subsequent open() of
+          * the "status" file of that entry, hence no time-of-check to
+          * time-of-use issue.
+          */
+         /* coverity[fs_check_call] */
          exeLen = readlink(cmdFilePath, exeRealPath, sizeof exeRealPath -1);
          if (exeLen != -1) {
             exeRealPath[exeLen] = '\0';
@@ -521,7 +526,13 @@ ProcMgr_ListProcesses(void)
        * stat() /proc/<pid> to get the owner.  We use fileStat.st_uid
        * later in this code.  If we can't stat(), ignore and continue.
        * Maybe we don't have enough permission.
+       *
+       * This stat() call on the current /proc entry is not intended
+       * as a check on the open() near the top of the while loop which
+       * is on the cmdline file of the next entry in /proc, hence no
+       * time-of-check to time-of-use issue.
        */
+      /* coverity[fs_check_call] */
       statResult = stat(cmdFilePath, &fileStat);
       if (0 != statResult) {
          goto next_entry;
@@ -1374,7 +1385,7 @@ ProcMgr_ExecSyncWithExitCode(char const *cmd,                  // IN: UTF-8 comm
                              Bool *validExitCode,              // OUT: exit code is valid
                              int *exitCode)                    // OUT: exit code
 {
-   Bool result = FALSE;
+   Bool result;
 
    ASSERT(exitCode != NULL && validExitCode != NULL);
 
@@ -1880,7 +1891,7 @@ ProcMgrKill(pid_t pid,      // IN
 {
    if (kill(pid, sig) == -1) {
       int savedErrno = errno;
-      Warning("Error trying to kill process %"FMTPID" with signal %d: %s\n",
+      Warning("Error trying to cancel process %"FMTPID" with signal %d: %s\n",
               pid, sig, Msg_ErrString());
       errno = savedErrno;
       return 0;
@@ -1927,7 +1938,7 @@ ProcMgrKill(pid_t pid,      // IN
    /*
     * timed out -- system/process is incredibly unresponsive or unkillable
     */
-   Warning("%s: timed out trying to kill pid %"FMTPID" with signal %d\n",
+   Warning("%s: timed out trying to cancel pid %"FMTPID" with signal %d\n",
            __FUNCTION__, pid, sig);
    return -1;
 }
