@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 1998-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 1998-2020 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -40,6 +40,7 @@
 #include "vmware.h"
 #include "buildNumber.h"
 #include "conf.h"
+#include "guestApp.h"
 #include "debug.h"
 #include "dynxdr.h"
 #include "hostinfo.h"
@@ -210,8 +211,8 @@ GuestInfoVMSupport(RpcInData *data)
 #if defined(_WIN32)
 
     char vmSupportCmd[] = "vm-support.vbs";
-    char *vmSupportPath = NULL;
-    gchar *vmSupport = NULL;
+    char *vmSupportPath;
+    gchar *vmSupport;
 
     SECURITY_ATTRIBUTES saProcess = {0}, saThread = {0};
 
@@ -990,10 +991,16 @@ GuestInfoSendNicInfoXdr(ToolsAppCtx *ctx,          // IN
                                &reply, &replyLen);
       if (!status) {
          g_warning("%s: update failed: request \"%s\", reply \"%s\".\n",
-                    __FUNCTION__, request, reply);
+                    __FUNCTION__, request, VM_SAFE_STR(reply));
       }
       vm_free(reply);
    }
+
+   /*
+    * DynXdr_Destroy only tries to free storage returned by a call to
+    * DynXdr_Create(NULL).
+    */
+   /* coverity[address_free] */
    DynXdr_Destroy(&xdrs, TRUE);
 
 exit:
@@ -1029,7 +1036,7 @@ GuestInfoSendData(ToolsAppCtx *ctx,                // IN
    Bool status;
    gchar *request;
    u_int msgLength = infoLength;
-   gchar *message = NULL;
+   gchar *message;
    char *reply = NULL;
    size_t replyLen;
 
@@ -1045,7 +1052,7 @@ GuestInfoSendData(ToolsAppCtx *ctx,                // IN
    status = RpcChannel_Send(ctx->rpc, message, msgLength, &reply, &replyLen);
    if (!status) {
       g_warning("%s: update failed: request \"%s\", reply \"%s\".\n",
-                __FUNCTION__, request, reply);
+                __FUNCTION__, request, VM_SAFE_STR(reply));
    }
    vm_free(reply);
 
@@ -1200,7 +1207,8 @@ GuestInfoSendNicInfo(ToolsAppCtx *ctx,             // IN
  * @param[in] infoSize  Size of disk info.
  *
  * @retval TRUE  Update sent successfully.
- * @retval FALSE Had trouble with serialization or transmission.
+ * @retval FALSE Had trouble with json string formatting, serialization or
+ *               transmission.
  *
  ******************************************************************************
  */
@@ -1216,7 +1224,7 @@ GuestInfoSendDiskInfoV1(ToolsAppCtx *ctx,             // IN
    char *infoReq;
    char *reply = NULL;
    size_t replyLen;
-   Bool status;
+   Bool status = FALSE;
 #ifdef _WIN32
    Bool reportUUID = VMTools_ConfigGetBoolean(ctx->config,
                                               CONFGROUPNAME_GUESTINFO,
@@ -1261,6 +1269,10 @@ GuestInfoSendDiskInfoV1(ToolsAppCtx *ctx,             // IN
 
    len = Str_Snprintf(tmpBuf, sizeof tmpBuf, headerFmt,
                       GUEST_DISK_INFO_COMMAND, DISK_INFO_VERSION_1);
+   if (len <= 0) {
+      goto exit;
+   }
+
    DynBuf_Append(&dynBuffer, tmpBuf, len);
    for (i = 0; i < pdi->numEntries; i++) {
       gchar *b64name;
@@ -1286,12 +1298,20 @@ GuestInfoSendDiskInfoV1(ToolsAppCtx *ctx,             // IN
                          b64name,
                          pdi->partitionList[i].freeBytes,
                          pdi->partitionList[i].totalBytes);
-      DynBuf_Append(&dynBuffer, tmpBuf, len);
       g_free(b64name);
+      if (len <= 0) {
+         goto exit;
+      }
+
+      DynBuf_Append(&dynBuffer, tmpBuf, len);
 
       if (pdi->partitionList[i].fsType[0] != '\0') {
          len = Str_Snprintf(tmpBuf, sizeof tmpBuf, jsonPerDiskFsTypeFmt,
                             pdi->partitionList[i].fsType);
+         if (len <= 0) {
+            goto exit;
+         }
+
          DynBuf_Append(&dynBuffer, tmpBuf, len);
       }
 #ifdef _WIN32
@@ -1299,6 +1319,10 @@ GuestInfoSendDiskInfoV1(ToolsAppCtx *ctx,             // IN
          if (pdi->partitionList[i].uuid[0] != '\0') {
             len = Str_Snprintf(tmpBuf, sizeof tmpBuf, jsonPerDiskUUIDFmt,
                                pdi->partitionList[i].uuid);
+            if (len <= 0) {
+               goto exit;
+            }
+
             DynBuf_Append(&dynBuffer, tmpBuf, len);
          }
       }
@@ -1310,11 +1334,19 @@ GuestInfoSendDiskInfoV1(ToolsAppCtx *ctx,             // IN
                        sizeof jsonPerDiskDevArrHdrFmt - 1);
          len = Str_Snprintf(tmpBuf, sizeof tmpBuf, jsonPerDiskDeviceFmt,
                             "", pdi->partitionList[i].diskDevNames[0]);
+         if (len <= 0) {
+            goto exit;
+         }
+
          DynBuf_Append(&dynBuffer, tmpBuf, len);
          for (idx = 1; idx < pdi->partitionList[i].diskDevCnt; idx++) {
             len = Str_Snprintf(tmpBuf, sizeof tmpBuf, jsonPerDiskDeviceFmt,
                                jsonPerDiskDeviceSep,
                                pdi->partitionList[i].diskDevNames[idx]);
+            if (len <= 0) {
+               goto exit;
+            }
+
             DynBuf_Append(&dynBuffer, tmpBuf, len);
          }
          DynBuf_Append(&dynBuffer, jsonPerDiskDevArrFmtFooter,
@@ -1343,12 +1375,13 @@ GuestInfoSendDiskInfoV1(ToolsAppCtx *ctx,             // IN
       }
    } else {
       g_debug("%s: RPC failed (%d) reply '%s'\n",
-              __FUNCTION__, status, reply ? reply : "");
+              __FUNCTION__, status, VM_SAFE_STR(reply));
    }
 
-   DynBuf_Destroy(&dynBuffer);
    vm_free(reply);
 
+exit:
+   DynBuf_Destroy(&dynBuffer);
    return status;
 }
 
@@ -1764,9 +1797,7 @@ static Bool
 DiskInfoChanged(const GuestDiskInfoInt *diskInfo)
 {
    int index;
-   char *name;
    int i;
-   int matchedPartition;
    GuestDiskInfoInt *cachedDiskInfo;
 
    cachedDiskInfo = gInfoCache.diskInfo;
@@ -1785,7 +1816,8 @@ DiskInfoChanged(const GuestDiskInfoInt *diskInfo)
 
    /* Have any disks been modified? */
    for (index = 0; index < cachedDiskInfo->numEntries; index++) {
-      name = cachedDiskInfo->partitionList[index].name;
+      int matchedPartition;
+      char *name = cachedDiskInfo->partitionList[index].name;
 
       /* Find the corresponding partition in the new partition info. */
       for (i = 0; i < diskInfo->numEntries; i++) {
