@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2008-2019 VMware, Inc. All rights reserved.
+ * Copyright (C) 2008-2020 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -28,6 +28,7 @@
 #include "vmware/guestrpc/tclodefs.h"
 #include "vmware/guestrpc/timesync.h"
 #include "vmware/tools/i18n.h"
+#include "vmware/tools/log.h"
 
 
 /*
@@ -113,7 +114,8 @@ TimeSyncEnable(void)
        TimeSyncSet(TRUE, &reply, &replyLen)) {
       ToolsCmd_Print("%s\n", SU_(option.enabled, "Enabled"));
    } else {
-      ToolsCmd_PrintErr(SU_(error.message, "Error: %s\n"), reply);
+      ToolsCmd_PrintErr(SU_(error.message, "Error: %s\n"),
+                        VM_SAFE_STR(reply));
       ret = EXIT_FAILURE;
    }
 
@@ -149,7 +151,8 @@ TimeSyncDisable(void)
        TimeSyncSet(FALSE, &reply, &replyLen)) {
       ToolsCmd_Print("%s\n", SU_(option.disabled, "Disabled"));
    } else {
-      ToolsCmd_PrintErr(SU_(error.message, "Error: %s\n"), reply);
+      ToolsCmd_PrintErr(SU_(error.message, "Error: %s\n"),
+                        VM_SAFE_STR(reply));
       ret = EXIT_FAILURE;
    }
 
